Composed permissions for django-rest-framework
----------------------------------------------

A simple way to define complex permissions for django-rest-framework.

- **Documentation:** https://djangorestframework-composed-permissions.readthedocs.org/en/latest/

Development
-----------

Run tests with our settings using the following command:

``django-admin test restfw_composed_permissions --settings=restfw_composed_permissions.tests.settings_sqlite``

License
-------

New BSD License
